Tractate

Enum Tractate 

pub enum Tractate {
Show 63 variants Berachos, Peah, Demai, Kilayim, Sheviis, Terumos, Maasros, MaaserSheni, Chalah, Orlah, Bikurim, Shabbos, Eruvin, Pesachim, Shekalim, Yoma, Sukkah, Beitzah, RoshHashanah, Taanis, Megillah, MoedKatan, Chagigah, Yevamos, Kesubos, Nedarim, Nazir, Sotah, Gitin, Kiddushin, BavaKamma, BavaMetzia, BavaBasra, Sanhedrin, Makkos, Shevuos, Eduyos, AvodahZarah, Avos, Horiyos, Zevachim, Menachos, Chullin, Bechoros, Arachin, Temurah, Kerisos, Meilah, Tamid, Midos, Kinnim, Keilim, Ohalos, Negaim, Parah, Taharos, Mikvaos, Niddah, Machshirin, Zavim, TevulYom, Yadayim, Uktzin,
}
A tractate of the Talmud (Bavli or Yerushalmi).

Variants



Berachos



Peah



Demai



Kilayim



Sheviis



Terumos



Maasros



MaaserSheni



Chalah



Orlah



Bikurim



Shabbos



Eruvin



Pesachim



Shekalim



Yoma



Sukkah



Beitzah



RoshHashanah



Taanis



Megillah



MoedKatan



Chagigah



Yevamos



Kesubos



Nedarim



Nazir



Sotah



Gitin



Kiddushin



BavaKamma



BavaMetzia



BavaBasra



Sanhedrin



Makkos



Shevuos



Eduyos



AvodahZarah



Avos



Horiyos



Zevachim



Menachos



Chullin



Bechoros



Arachin



Temurah



Kerisos



Meilah



Tamid



Midos



Kinnim



Keilim



Ohalos



Negaim



Parah



Taharos



Mikvaos



Niddah



Machshirin



Zavim



TevulYom



Yadayim



Uktzin